@@ -7,7 +7,9 @@
  * On most BSDs they come automatically
  * On other platforms - I have no idea... bug reports welcome :)
  */
-#define _GNU_SOURCE
+#ifndef _GNU_SOURCE
+# define _GNU_SOURCE
+#endif
 
 #include "tickit.h"
 #include "bindings.h"
@@ -170,15 +172,15 @@ TickitTerm *tickit_term_build(const struct TickitTermBuilder *_builder)
   if(!tt)
     return NULL;
 
-  TickitTermDriver *driver = tickit_term_build_driver(&builder);
-  if(!driver)
-    return NULL;
-
   if(builder.ti_hook)
     tt->ti_hook = *builder.ti_hook;
   else
     tt->ti_hook = (struct TickitTerminfoHook){ 0 };
 
+  TickitTermDriver *driver = tickit_term_build_driver(&builder);
+  if(!driver)
+    return NULL;
+
   tt->outfd   = -1;
   tt->outfunc = NULL;
 
